@@ -1,13 +1,12 @@
 from smtplib import SMTPException
 from uuid import UUID
-
+import strawberry
 from django.core.signing import BadSignature, SignatureExpired
 from django.core.exceptions import ObjectDoesNotExist
 from django.contrib.auth import get_user_model
 from django.contrib.auth.forms import SetPasswordForm, PasswordChangeForm
 from django.db import transaction
 from django.utils.module_loading import import_string
-
 from strawberry_django_jwt.exceptions import JSONWebTokenError, JSONWebTokenExpired
 
 from gqlauth.forms import (
@@ -16,6 +15,7 @@ from gqlauth.forms import (
     UpdateAccountForm,
     PasswordLessRegisterForm,
 )
+from gqlauth.types import CaptchaType
 from gqlauth.utils import normalize_fields, g_user
 from gqlauth.models import Captcha, UserStatus
 from gqlauth.settings import gqlauth_settings as app_settings
@@ -49,6 +49,12 @@ else:
     async_email_func = None
 
 
+class Cap:
+    @strawberry.mutation
+    def Field(self, info) -> CaptchaType:
+        return Captcha.create_captcha()
+
+
 class RegisterMixin:
     """
     Register user with fields defined in the settings.
@@ -440,7 +446,7 @@ class ObtainJSONWebTokenMixin:
     def check_captcha(cls, **input_):
         uuid = input_.get("identifier")
         try:
-            obj = Captcha.objects.get(id=uuid)
+            obj = Captcha.objects.get(uuid=uuid)
         except Captcha.DoesNotExist:
             return Messages.CAPTCHA_EXPIRED
 
